@@ -2,7 +2,7 @@
 sentry.manager
 ~~~~~~~~~~~~~~
 
-:copyright: (c) 2010 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 
@@ -276,7 +276,6 @@ class GroupManager(models.Manager, ChartMixin):
             data=data,
             server_name=server_name,
             site=site,
-            checksum=checksum,
             time_spent=time_spent,
             datetime=date,
             **kwargs
@@ -286,6 +285,8 @@ class GroupManager(models.Manager, ChartMixin):
         if not checksum:
             checksum = get_checksum_from_event(event)
 
+        event.checksum = checksum
+
         group_kwargs = kwargs.copy()
         group_kwargs.update({
             'last_seen': date,
